@@ -59,8 +59,14 @@ def blank_score(det_pred,prob_pred,target):
     return len(target)
 
 def ROC_AUC(det_pred,prob_pred,target,**score_kwargs):
+    
+    #No ROC_AUC for a variable with only one value
+    if len(np.unique(target))==1:
+        return np.nan
     if len(np.unique(target))==2:
         prob_pred=prob_pred[:,1]
+        
+    
     return roc_auc_score(target,prob_pred,**score_kwargs)
 
 class PredictionTest(object):
@@ -215,7 +221,7 @@ class PredictionTest(object):
         cv_iterator=cv_method(predictors,target,**cv_kwargs)
         return cv_iterator
     
-    def add_score_to_index_metadata(self,indices,label='score',raise_on_missing_var=False,reduce_func=np.mean):
+    def add_score_to_index_metadata(self,indices,label='score',raise_on_missing_var=False,reduce_func=np.nanmean):
         s=self.computed_scores
         if s is None:
             raise(ValueError('No scores computed.'))
